@@ -1,8 +1,12 @@
 #!/bin/sh
-readonly TESTLIB="./test-func"
+# Note: the simulation is intended to run on a ThinkPad, which has a superset
+# of all battery care features
+
+readonly TESTLIB="test-func"
+spath="${0%/*}"
 # shellcheck disable=SC1090
-. $TESTLIB || {
-    printf "Error: missing library %s\n" "${TESTLIB}" 1>&2
+. "$spath/$TESTLIB" || {
+    printf "Error: missing library %s\n" "$spath/$TESTLIB" 1>&2
     exit 70
 }
 
@@ -24,16 +28,17 @@ else
     exit 1
 fi
 
+export VWRITE_SLEEP=2
 export xinc="X_BAT_PLUGIN_SIMULATE=cros-ec X_BAT_CROSCC_SIMULATE_ECVER=2"
 sudo tlp setcharge ${bata} 35 100 > /dev/null 2>&1 # preset start threshold for simulation
-./test-bc_cros-ec-v2.sh "(cros_charge-control)"
+"$spath/test-bc_cros-ec-v2.sh" "(cros_charge-control)"
 
 export xinc="X_BAT_PLUGIN_SIMULATE=framework"
 sudo tlp setcharge ${bata} 35 100 > /dev/null 2>&1 # preset start threshold for simulation
-./test-bc_cros-ec-v2.sh "(framework)"
+"$spath/test-bc_cros-ec-v2.sh" "(framework)"
 
 export xinc="X_BAT_PLUGIN_SIMULATE=cros-ec"
-./test-bc_cros-ec-v3.sh
+"$spath/test-bc_cros-ec-v3.sh"
 
 sudo tlp setcharge ${bata}  > /dev/null 2>&1 # reset test machine to configured thresholds
 
